@@ -12,9 +12,9 @@ from . import SizeDistributionBaseModel as PSDBase
 class LogNormal(PSDBase.SizeDistributionBaseModel):
     def __init__(self) -> None:
         super().__init__()
-        self.model_par_str: List[str] = ["D50", "delta"]
+        self.model_par_str: List[str] = ["Dm", "delta"]
         self.model_expression_str: str = (
-            "X(d) = 0.5*[1 + erf(Z)]; Z = ln(d/D50) / [(sqrt(2) * ln(delta) ) ]"
+            "X(d) = 0.5*[1 + erf(Z)]; Z = ln(d/Dm) / [(sqrt(2) * ln(delta) ) ]"
         )
 
         self.model_name_str: str = "Log-normal"
@@ -41,4 +41,4 @@ class LogNormal(PSDBase.SizeDistributionBaseModel):
         return float(D50 * np.exp(-0.5 * np.log(delta) ** 2))
 
     def getSauterDiameterExpression(self) -> str:
-        return "dps = D50*exp(-0.5 * ln(delta)^2)"
+        return "dps = Dm*exp(-0.5 * ln(delta)^2)"
